@@ -1,5 +1,5 @@
 #!/usr/bin/python
-# $Id: owfs.py 1013 2014-08-21 12:03:23Z mwall $
+# $Id: owfs.py 1020 2014-08-26 18:20:40Z mwall $
 #
 # Copyright 2013 Matthew Wall
 # Thanks to Mark Cressey (onewireweewx) and Howard Walter (TAI code).
@@ -394,7 +394,7 @@ class OWFS(weewx.abstractstation.AbstractStation):
                     if st in self.sensor_types:
                         func = self.sensor_types[st]
                         p[s] = func(s, self.sensor_map[s],
-                                    self.last_data, p['dateTime'])
+                                    last_data, p['dateTime'])
                     else:
                         logerr("unknown sensor type '%s' for %s" % (st, s))
                 ntries = 0
